import argparse


unhandled_exit = None


def check_positive(value):
    ivalue = int(value)
    if ivalue <= 0:
        raise argparse.ArgumentTypeError("%s is an invalid positive int value"
                                         % value)
    return ivalue


def pytest_addoption(parser):
    group = parser.getgroup('unhandled_exc_exit_code')
    group.addoption(
        '--unhandled-exc-exit-code',
        action='store',
        default=13,
        type=int,
        choices=range(0, 256),
        help='Use this exit code if there was an unhandled exception.'
    )


def pytest_exception_interact(node, call, report):
    """
    Set a different exit code on uncaught exceptions.
    """
    global unhandled_exit
    exctype, value, traceback = call.excinfo._excinfo

    if exctype == AssertionError:
        return report
    unhandled_exit = node.config.getoption('--unhandled-exc-exit-code')


def pytest_sessionfinish(session, exitstatus):
    if unhandled_exit is not None:
        session.exitstatus = unhandled_exit



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

readme = open('README.rst').read()

requirements = [
    'pytest>=2.3'
]

setup(
    name='pytest-unhandled-exception-exit-code',
    version='0.0.1',
    description='Plugin for py.test set a different exit code on uncaught '
                'exceptions',
    long_description=readme + '\n',
    author='NAGY, Attila',
    author_email='nagy.attila+pytest@gmail.com',
    url='https://github.com/bra-fsn/pytest-unhandled-exception-exit-code',
    py_modules=['pytest_unhandled_exception_exit_code'],
    entry_points={'pytest11': ['pytest_unhandled_exception_exit_code = pytest_unhandled_exception_exit_code']},
    include_package_data=True,
    install_requires=requirements,
    license="BSD",
    zip_safe=False,
    keywords='pytest,py.test',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Framework :: Pytest',
    ],
)
